/**
 * Component: pbdcm
 *
 * Description:
 *     Header file for PB Custom Fields class manipulating custom fields
 * 
 *
 * Last Updated     : $Author$
 * Update Date Time : $Date$
 * RCS File Name    : $RCSfile$
 * RCS Revision     : $Revision$
 * Locked by        : $Locker$
 * Symbolic name    : $Name$
 * State            : $State$
 */

#ifndef PBCUSTOMPROPERTIES_H_
#define PBCUSTOMPROPERTIES_H_

#include <dcmtk/dcmdata/dctk.h>

/**
 * Manipulating PB custom defined fields in DICOM objects
 */
class PBCustomFields {
	private:

		/** Dataset of the DICOM file */
		DcmDataset & m_dataset;

		/** PB Custom Fields sequence */
		DcmSequenceOfItems * m_customFieldsSeq;

	public:

		/**
		 * Constructor for creating a new PB Custom Fields object
		 *
		 * @param dataset  dataset of the DICOM object
		 */
		PBCustomFields( DcmDataset & dataset );

		/**
		 * Destructor for destroying the PB Custom Fields object
		 */
		virtual ~PBCustomFields();

		/**
		 * Returns value for the custom defined field
		 *
		 * @param fieldName  name of the custom defined field
		 *
		 * @return  field value or NULL if no such field in the DICOM object
		 */
		const char * getFieldValue( const char * fieldName ) const;

		/**
		 * Sets value for custom defined field.
		 * If value is NULL, the field will be deleted from the DICOM object
		 *
		 * @param fieldName   name of the custom defined field
		 * @param value       new value for the custom defined field
		 *
		 * @return true if and only if the new value was successfully set for the field
		 */
		bool setFieldValue( const char * fieldName, const char * value );

		/**
		 * Return the field names currently set in the DICOM object.
		 * Field names will be returned in the nameList parameter (will be cleared first).
		 *
		 * @param nameList  output parameter for the custom defined field names
		 */
		void fieldNames( OFList< OFString > & nameList ) const;
};

#endif /* PBCUSTOMPROPERTIES_H_ */
